| Title: | Development Tools for 'SpaDES' and 'SpaDES' Modules |
|---|---|
| Description: | Provides 'RStudio' addins for 'SpaDES' packages and 'SpaDES' module development. See '?SpaDES.addins' for an overview of the tools provided. |
| Authors: | Alex M Chubaty [aut, cre] (ORCID: <https://orcid.org/0000-0001-7146-8135>), His Majesty the King in Right of Canada, as represented by the Minister of Natural Resources Canada [cph] |
| Maintainer: | Alex M Chubaty <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.4.9000 |
| Built: | 2026-06-08 05:45:04 UTC |
| Source: | https://github.com/PredictiveEcology/SpaDES.addins |
SpaDES.addins packageProvides 'RStudio' addins for 'SpaDES' packages and 'SpaDES' module development.
SpaDES module developmentRStudio addins:
copy an existing SpaDES module
create a new SpaDES module
clear recent simulation cache entries
helper functions:
none yet
Maintainer: Alex M Chubaty [email protected] (ORCID)
Other contributors:
His Majesty the King in Right of Canada, as represented by the Minister of Natural Resources Canada [copyright holder]
Useful links:
Report bugs at https://github.com/PredictiveEcology/SpaDES.addins/issues
RStudio addin to clear recent cache entries
addin_clearCache()addin_clearCache()
Alex Chubaty
RStudio addin to copy an existing module
addin_copyModule()addin_copyModule()
Alex Chubaty
RStudio addin to create a new module
addin_newModule()addin_newModule()
Alex Chubaty